# -*- coding: utf-8 -*-
from cpskin.policy.setuphandlers import add_cookiescuttr
from cpskin.policy.setuphandlers import configure_autopublish
from cpskin.policy.setuphandlers import ensure_folder_ordering
from cpskin.policy.setuphandlers import set_scales_for_image_cropping
from plone import api
from plone.app.workflow.remap import remap_workflow
from Products.CMFCore.utils import getToolByName
from zope.component import queryUtility
from zope.dottedname.resolve import resolve
from zope.ramcache.interfaces.ram import IRAMCache

import logging
import transaction


def install_collective_captchacontactinfo(context, logger=None):
    if logger is None:
        # Called as upgrade step: define our own logger.
        logger = logging.getLogger('cpskin.policy')
    portal_setup = api.portal.get_tool('portal_setup')
    portal_setup.runAllImportStepsFromProfile(
            'profile-collective.captchacontactinfo:default')
    logger.info('collective.captchacontactinfo installed')
    contactinfo_properties = api.portal.get_tool("portal_properties").contactinfo_properties
    contactinfo_properties.policy_page = "gdpr-view"


def install_auto_publishing(context, logger=None):
    if logger is None:
        # Called as upgrade step: define our own logger.
        logger = logging.getLogger('cpskin.policy')
    portal_setup = api.portal.get_tool('portal_setup')
    portal_setup.runAllImportStepsFromProfile(
            'profile-collective.autopublishing:default')
    logger.info('collective.autopublishing installed')
    configure_autopublish()


def uninstall_restapi(context, logger=None):
    if logger is None:
        # Called as upgrade step: define our own logger.
        logger = logging.getLogger('cpskin.policy')
    portal_setup = api.portal.get_tool('portal_setup')
    portal_setup.runAllImportStepsFromProfile(
            'profile-plone.restapi:uninstall')
    portal_quickinstaller = api.portal.get_tool('portal_quickinstaller')
    portal_quickinstaller.uninstallProducts(['plone.restapi'])
    logger.info('plone.restapi uninstalled')


def install_restapi(context, logger=None):
    if logger is None:
        # Called as upgrade step: define our own logger.
        logger = logging.getLogger('cpskin.policy')
    portal_setup = api.portal.get_tool('portal_setup')
    portal_setup.runAllImportStepsFromProfile(
            'profile-plone.restapi:default')
    logger.info('plone.restapi installed')


def update_font_to_https(context, logger=None):
    if logger is None:
        # Called as upgrade step: define our own logger.
        logger = logging.getLogger('cpskin.policy')
    portal_css = api.portal.get_tool('portal_css')
    for sheet in portal_css.getResources():
        sheet_id = sheet.getId()
        if 'fonts.googleapis.com' in sheet_id:
            if not sheet_id.startswith('https://'):
                # portal_css.unregisterResource(sheetid)
                new_id = sheet_id.replace('http://', 'https://')
                portal_css.renameResource(sheet_id, new_id)
                logger.info('{0} replaced by {1}'.format(sheet_id, new_id))
    portal_css.cookResources()


def update_links(context, logger=None):
    if logger is None:
        # Called as upgrade step: define our own logger.
        logger = logging.getLogger('cpskin.policy')
    portal_catalog = api.portal.get_tool('portal_catalog')
    brains = portal_catalog({'portal_type': 'Link'})
    i = 0
    for brain in brains:
        obj = brain.getObject()
        if obj.remoteUrl.startswith('resolveuid'):
            new_url = '${{navigation_root_url}}/{0}'.format(obj.remoteUrl)
            obj.remoteUrl = new_url
            logger.info('{0} update'.format(obj.absolute_url()))
            i += 1
    logger.info('{0} links updated'.format(str(i)))
    update_font_to_https(context, logger)


def remove_old_contentleadimage(context, logger=None):
    if logger is None:
        # Called as upgrade step: define our own logger.
        logger = logging.getLogger('cpskin.policy remove_old_contentleadimage')
    portal = api.portal.get()
    sm = portal.getSiteManager()

    utilities = {
            'subscribers': sm.utilities._subscribers[0],
            'adapters': sm.utilities._adapters[0],
            # 'provided': sm.utilities._provided
            }
    util_klass = resolve('plone.browserlayer.interfaces.ILocalBrowserLayerType')
    reg_klass = resolve('collective.contentleadimage.interfaces.ILeadImageSpecific')
    for sm_type in utilities.keys():
        utility_registrations = utilities[sm_type]
        for x in utility_registrations.keys():
            if x.__module__ == util_klass.__module__ and x == util_klass:
                for name, klass in utility_registrations[x].items():
                    found = find_object_or_class(klass, reg_klass)
                    # if found:
                    #     import pdb; pdb.set_trace()
                    if found:
                        if type(utility_registrations[x][name]) in \
                                [list, tuple, set]:
                            regs = list(utility_registrations[x][name])
                            regs.remove(found)
                            logger.info('{0} {1} removed'.format(sm_type, reg_klass))
                            utility_registrations[x][name] = tuple(regs)
                        else:
                            logger.info('{0} removed'.format(name))
                            del utility_registrations[x][name]

        setattr(sm.utilities, '_' + sm_type, [utility_registrations])


def install_collective_limitfilesizepanel(context, logger=None):
    if logger is None:
        # Called as upgrade step: define our own logger.
        logger = logging.getLogger('cpskin.policy')

    portal_setup = api.portal.get_tool('portal_setup')
    portal_setup.runAllImportStepsFromProfile(
            'profile-collective.limitfilesizepanel:default')
    logger.info('collective.limitfilesizepanel installed')


def add_cpskin_collective_contact_workflow(context):
    context.runImportStepFromProfile('profile-cpskin.workflow:to1', 'workflow')
    chain = ('cpskin_collective_contact_workflow',)
    types = ('held_position',
            'organization',
            'person',
            'position')
    state_map = {'active': 'active',
            'deactivated': 'deactivated'}
    remap_workflow(context, type_ids=types, chain=chain,
            state_map=state_map)
    util = queryUtility(IRAMCache)
    if util is not None:
        util.invalidateAll()

    # set a workflow version
    context.runAllImportStepsFromProfile('profile-cpskin.workflow:default')


def delete_multilingualbehavior(context, logger=None):
    if logger is None:
        # Called as upgrade step: define our own logger.
        logger = logging.getLogger('cpskin.policy')

    portal = api.portal.get()
    sm = portal.getSiteManager()

    portal_setup = getToolByName(context, 'portal_setup')
    portal_setup.runAllImportStepsFromProfile(
            'profile-plone.multilingualbehavior:uninstall')

    # Check is PAM is installed, if not remore plone.multilingual
    portal_quickinstaller = getToolByName(context, 'portal_quickinstaller')
    portal_quickinstaller.uninstallProducts(['plone.multilingualbehavior'])
    logger.info('plone.multilingualbehavior uninstalled')

    portal_setup.runAllImportStepsFromProfile(
            'profile-plone.multilingual:uninstall')
    portal_quickinstaller.uninstallProducts(['plone.multilingual'])
    logger.info('plone.multilingual uninstalled')

    subscribers = sm.adapters._subscribers
    for i, sub in enumerate(subscribers):
        for key in sub.keys():
            if 'multilingual' in str(key):
                del subscribers[i][key]
                logger.info('Deleted {0} subscriber'.format(key))
    sm.adapters._subscribers = subscribers

    transaction.commit()
    app = portal.restrictedTraverse('/')
    app._p_jar.sync()


def install_collective_atomrss(context, logger=None):
    if logger is None:
        # Called as upgrade step: define our own logger.
        logger = logging.getLogger('cpskin.policy')

    setup_tool = getToolByName(context, 'portal_setup')
    setup_tool.runAllImportStepsFromProfile(
            'profile-collective.atomrss:default')
    logger.info('collective.atomrss installed')


def install_collective_cookiecuttr(context, logger=None):
    setup = getToolByName(context, 'portal_setup')
    setup.runAllImportStepsFromProfile(
            'profile-collective.cookiecuttr:default')
    portal = api.portal.get()
    add_cookiescuttr(portal)


def clean_registries(context, logger=None):
    if logger is None:
        # Called as upgrade step: define our own logger.
        logger = logging.getLogger('cpskin.policy.upgrades')
    portal = api.portal.get()
    logger.info('Cleaning registries...')

    jstool = portal.portal_javascripts
    jstool.cookResources()
    logger.info('portal_javascripts has been cleaned!')

    csstool = portal.portal_css
    csstool.cookResources()
    logger.info('portal_css has been cleaned!')
    ps = portal.portal_setup
    # clean portal_setup
    for stepId in ps.getSortedImportSteps():
        stepMetadata = ps.getImportStepMetadata(stepId)
        # remove invalid steps
        if stepMetadata['invalid']:
            logger.info('Removing {0} step from portal_setup'.format(stepId))
            ps._import_registry.unregisterStep(stepId)
            ps._p_changed = True
    logger.info('portal_setup has been cleaned!')

    logger.info('Registries have been cleaned!')


def install_image_cropping(context, logger=None):
    if logger is None:
        # Called as upgrade step: define our own logger.
        logger = logging.getLogger('cpskin.policy')

    setup_tool = getToolByName(context, 'portal_setup')
    setup_tool.runAllImportStepsFromProfile(
            'profile-plone.app.imagecropping:default')
    logger.info('plone.app.imagecropping installed')


def set_allowed_sizes(context, logger=None):
    if logger is None:
        # Called as upgrade step: define our own logger.
        logger = logging.getLogger('cpskin.policy')

    setup_tool = getToolByName(context, 'portal_setup')
    setup_tool.runImportStepFromProfile(
            'profile-cpskin.policy:default', 'propertiestool')
    setup_tool.runImportStepFromProfile(
            'profile-cpskin.policy:default', 'plone.app.registry')
    set_scales_for_image_cropping()
    clean_registries(context)
    logger.info('cpskin.policy updated')


def find_object_or_class(objs, klass):
    if type(objs) not in [list, tuple, set]:
        objs = [objs]
    for obj in objs:
        if klass == obj:
            return obj

    return None


def reload_css_registry(context, logger=None):
    if logger is None:
        # Called as upgrade step: define our own logger.
        logger = logging.getLogger("cpskin.policy")

    setup_tool = getToolByName(context, "portal_setup")
    setup_tool.runImportStepFromProfile("profile-cpskin.policy:default", "cssregistry")


def improve_eea_expression(context, logger=None):
    if logger is None:
        # Called as upgrade step: define our own logger.
        logger = logging.getLogger("cpskin.policy")

    eea_expression = "python:'configure_faceted.html' in request.URL0"
    eea_fixed_expression = "python:'URL0' in request and 'configure_faceted.html' in request.URL0"
    portal = api.portal.get()
    for tool_id in ["portal_javascripts", "portal_css"]:
        tool = api.portal.get_tool(tool_id)
        resources = tool.getResources()
        for resource in resources:
            if resource.getExpression() == eea_expression:
                resource.setExpression(eea_fixed_expression)
                logger.info(
                    "Resource {0} expression has been fixed in {1}".format(
                        resource.getId(), tool_id
                    )
                )


def upgrade_ensure_folder_ordering(context):
    ensure_folder_ordering()



# -*- coding: utf-8 -*-
from plone.app.robotframework.testing import REMOTE_LIBRARY_BUNDLE_FIXTURE
from plone.app.testing import applyProfile
from plone.app.testing import FunctionalTesting
from plone.app.testing import IntegrationTesting
from plone.app.testing import PloneWithPackageLayer
from plone.testing import z2

import cpskin.policy


class CpskinPolicyPloneWithPackageLayer(PloneWithPackageLayer):
    """
    """
    def setUpZope(self, app, configurationContext):
        super(CpskinPolicyPloneWithPackageLayer, self).setUpZope(
            app,
            configurationContext)
        z2.installProduct(app, 'Products.DateRecurringIndex')

    def tearDownZope(self, app):
        # Uninstall products installed above
        z2.uninstallProduct(app, 'Products.DateRecurringIndex')

    def setUpPloneSite(self, portal):
        portal.portal_workflow.setDefaultChain('simple_publication_workflow')
        applyProfile(portal, 'cpskin.policy:testing')
        applyProfile(portal, 'cpskin.demo:default')


CPSKIN_POLICY_FIXTURE = CpskinPolicyPloneWithPackageLayer(
    name='CPSKIN_POLICY_FIXTURE',
    zcml_filename='testing.zcml',
    zcml_package=cpskin.policy,
    additional_z2_products=('Products.PasswordStrength',),
    gs_profile_id='cpskin.policy:testing')

CPSKIN_POLICY_INTEGRATION_TESTING = IntegrationTesting(
    bases=(CPSKIN_POLICY_FIXTURE,),
    name='CPSkinPolicy:Integration')

CPSKIN_POLICY_ROBOT_TESTING = FunctionalTesting(
    bases=(CPSKIN_POLICY_FIXTURE,
           REMOTE_LIBRARY_BUNDLE_FIXTURE,
           z2.ZSERVER_FIXTURE),
    name='cpskin.policy:Robot')



# -*- coding: utf-8 -*-
from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
from zope.publisher.browser import BrowserView


class CookiesPage(BrowserView):

    index = ViewPageTemplateFile('templates/cookies.pt')

    def __init__(self, context, request):
        super(CookiesPage, self).__init__(context, request)
        # self.city_name = api.portal.get_registry_record(
        #     'cpskin.core.interfaces.ICPSkinSettings.city_name')
        # portal = api.portal.get()
        # self.site_id = portal.getId()



# -*- coding: utf-8 -*-

from Acquisition import aq_inner
from Acquisition import aq_parent
from collective.preventactions.interfaces import IPreventDelete
from collective.preventactions.interfaces import IPreventMoveOrRename
from OFS.interfaces import IOrderedContainer
from Products.BTreeFolder2.BTreeFolder2 import BTreeFolder2Base
from Products.Five.browser import BrowserView
from plone import api
from plone.app.contenttypes.migration import dxmigration
from plone.app.folder.utils import timer
from plone.folder.interfaces import IOrdering
from time import strftime
from zope.interface import alsoProvides
from zope.interface import noLongerProvides
import logging

logger = logging.getLogger("cpskin.policy")


class FolderishTypesMigrationView(BrowserView):
    """ Installs collective.folderishtypes and migrate existing contents """

    def mklog(self):
        """ Helper to prepend a time stamp to the output """
        write = self.request.RESPONSE.write

        def log(msg, level="info"):
            if level == "warn":
                logger.warn(msg)
            else:
                logger.info(msg)
            msg = "{0} {1}\n".format(strftime("%d/%m/%Y - %H:%M:%S"), msg)
            write(msg)

        return log

    def install_folderish_types(self):
        portal_setup = api.portal.get_tool("portal_setup")
        portal_setup.runAllImportStepsFromProfile(
            "profile-collective.folderishtypes.dx:default"
        )

    def fix_folderish_types(self):
        log = self.mklog()
        catalog = api.portal.get_tool("portal_catalog")
        ordering_nb = btree_nb = 0
        for brain in catalog():
            obj = brain.getObject()
            is_container = isinstance(obj, BTreeFolder2Base)
            if not is_container:
                continue
            if not IOrdering.providedBy(obj):
                alsoProvides(obj, IOrdering)
                obj.reindexObject(["object_provides"])
                ordering_nb += 1
            if obj._tree is None:
                BTreeFolder2Base._initBTrees(obj)
                btree_nb += 1
        log("{0} objects IOrdering interface have been fixed.".format(ordering_nb))
        log("{0} objects tree have been fixed.".format(btree_nb))

    def __call__(self):
        log = self.mklog()
        real = timer()

        self.install_folderish_types()
        log("collective.folderishtypes installed.")

        catalog = api.portal.get_tool("portal_catalog")
        catalog.clearFindAndRebuild()
        log("Portal catalog has been rebuilt.")

        changed_base_classes = [
            "plone.app.contenttypes.content.Document",
            "plone.app.contenttypes.content.NewsItem",
            "plone.app.contenttypes.content.Event",
        ]

        migrated = []
        not_migrated = []
        for brain in catalog():
            obj = brain.getObject()
            old_class_name = dxmigration.get_old_class_name_string(obj)
            if old_class_name in changed_base_classes:
                prevented_delete = prevented_move = False
                obj_id = obj.getId()
                parent = aq_parent(aq_inner(obj))
                if IPreventDelete.providedBy(obj):
                    prevented_delete = True
                    noLongerProvides(obj, IPreventDelete)
                if IPreventMoveOrRename.providedBy(obj):
                    prevented_move = True
                    noLongerProvides(obj, IPreventMoveOrRename)
                position_in_parent = None
                ordered = IOrderedContainer(parent, None)
                if ordered is not None:
                    position_in_parent = ordered.getObjectPosition(obj_id)
                if dxmigration.migrate_base_class_to_new_class(
                    obj, migrate_to_folderish=True
                ):
                    migrated.append(obj)
                    if position_in_parent is not None:
                        ordered.moveObject(obj_id, position_in_parent)
                    if prevented_delete:
                        alsoProvides(obj, IPreventDelete)
                    if prevented_move:
                        alsoProvides(obj, IPreventMoveOrRename)
                else:
                    not_migrated.append(obj)

        if migrated:
            log("{0} objects have been migrated.".format(len(migrated)))
        if not_migrated:
            log(
                "{0} objects have NOT been migrated.".format(len(not_migrated)),
                level="warn",
            )

        catalog.clearFindAndRebuild()
        log("Portal catalog has been rebuilt.")

        msg = "Processed folderish types migration in {0}.".format(real.next())
        log(msg)



# -*- coding: utf-8 -*-
from cpskin.policy.interfaces import ICPSkinPolicyLayer
from cpskin.policy.testing import CPSKIN_POLICY_INTEGRATION_TESTING
from plone.app.testing import applyProfile
from plone.browserlayer.utils import registered_layers

import unittest


class TestProfiles(unittest.TestCase):

    layer = CPSKIN_POLICY_INTEGRATION_TESTING

    def setUp(self):
        self.portal = self.layer['portal']

    def test_package_installed(self):
        self.assertIn(ICPSkinPolicyLayer, registered_layers(),
                      'Browserlayers appears not loaded')

    def test_uninstall(self):
        applyProfile(self.portal, 'cpskin.policy:uninstall')

    def test_reinstall(self):
        applyProfile(self.portal, 'cpskin.policy:uninstall')
        applyProfile(self.portal, 'cpskin.policy:default')



# -*- coding: utf-8 -*-
from collective.autopublishing.browser.autopublishsettings import AutopublishSpecification
from collective.autopublishing.browser.autopublishsettings import IAutopublishSettingsSchema
from collective.complexrecordsproxy import ComplexRecordsProxy
from cpskin.core.interfaces import IFolderViewSelectedContent
from cpskin.locales import CPSkinMessageFactory as _
from plone import api
from plone.app.event.interfaces import IEventSettings
from plone.app.workflow.remap import remap_workflow
from plone.contentrules.engine.interfaces import IRuleStorage
from plone.folder.default import DefaultOrdering
from plone.registry.interfaces import IRegistry
from Products.ATContentTypes.lib import constraintypes
from Products.CMFCore.utils import getToolByName
from Products.CMFPlone.interfaces.syndication import IFeedSettings
from Products.CMFPlone.utils import _createObjectByType
from zope.annotation.interfaces import IAnnotations
from zope.component import getUtility
from zope.component import queryUtility
from zope.interface import alsoProvides
from zope.ramcache.interfaces.ram import IRAMCache

import logging
import os


logger = logging.getLogger('cpskin.policy')
timezone = 'Europe/Brussels'


def publishContent(wftool, content):
    if wftool.getInfoFor(content, 'review_state') != 'published':
        actions = [a.get('id') for a in wftool.listActions(object=content)]
        # we need to handle both workflows
        if 'publish_and_hide' in actions:
            wftool.doActionFor(content, 'publish_and_hide')
        elif 'publish' in actions:
            wftool.doActionFor(content, 'publish')


def installPolicy(context):
    if context.readDataFile('cpskin.policy-default.txt') is None:
        return

    logger.info('Installing policy')
    default_language = 'fr'
    portal_languages = api.portal.get_tool('portal_languages')
    portal_languages.setDefaultLanguage(default_language)
    supported = portal_languages.getSupportedLanguages()
    portal_languages.removeSupportedLanguages(supported)
    portal_languages.addSupportedLanguage(default_language)

    # set plone.app.event
    reg = getUtility(IRegistry)
    settings = reg.forInterface(IEventSettings, prefix='plone.app.event')
    if not settings.portal_timezone:
        logger.info('Set timezone to Europe/Brussels')
        settings.portal_timezone = timezone
        settings.first_weekday = 0
        settings.available_timezones = [timezone]

    portal = api.portal.get()

    # review_state
    review_index = 'review_state'
    review_operator = 'plone.app.querystring.operation.selection.is'
    review_states = ['published_and_hidden', 'published_and_shown']

    setCriterion(portal=portal,
                 folder_name='actualites',
                 index=review_index,
                 operator=review_operator,
                 value=review_states)
    setCriterion(portal=portal,
                 folder_name='evenements',
                 index=review_index,
                 operator=review_operator,
                 value=review_states)

    # expires
    not_expired_index = 'expires'
    not_expired_operator = 'plone.app.querystring.operation.date.afterToday'

    setCriterion(portal=portal,
                 folder_name='actualites',
                 index=not_expired_index,
                 operator=not_expired_operator)
    setCriterion(portal=portal,
                 folder_name='evenements',
                 index='end',
                 operator='plone.app.querystring.operation.date.afterToday')

    renameIndexhtml(portal)
    portal.setLayout('folderview')

    add_alaune(portal)
    create_menu(portal)
    add_cookiescuttr(portal)
    set_scales_for_image_cropping()
    enable_sitemap(portal)
    add_mail_host()
    # use_email_as_login()
    set_contact_worflow()
    configure_autopublish()
    ensure_folder_ordering()


def configure_autopublish():
    settings = getUtility(IRegistry).forInterface(
        IAutopublishSettingsSchema,
        omit=('publish_actions', 'retract_actions'),
        factory=ComplexRecordsProxy)

    publish_action = AutopublishSpecification(
        {
            'portal_types': (u'News Item', 'Event'),
            'initial_state': u'created',
            'transition': u'publish_and_hide',
        }
    )
    settings.publish_actions = (publish_action,)

    retract_action = AutopublishSpecification(
        {
            'portal_types': (u'News Item', 'Event'),
            'initial_state': u'published_and_hidden',
            'transition': u'back_to_created',
        }
    )
    retract_action.date_index = u'expires'
    settings.retract_actions = (retract_action,)
    settings.dry_run = False


def renameIndexhtml(portal):
    if portal.get('index_html'):
        # Should be deteled
        api.content.rename(obj=portal['index_html'], new_id='index_html.old')


def uninstallPolicy(context):
    if context.readDataFile('cpskin.policy-uninstall.txt') is None:
        return

    logger.info('Uninstalling policy')
    portal = context.getSite()
    deleteContentRules(portal)

    review_index = 'review_state'
    review_operator = 'plone.app.querystring.operation.selection.is'
    review_state = ['published']

    setCriterion(portal=portal,
                 folder_name='actualites',
                 index=review_index,
                 operator=review_operator,
                 value=review_state)
    setCriterion(portal=portal,
                 folder_name='evenements',
                 index=review_index,
                 operator=review_operator,
                 value=review_state)


def createEventsAndNews(portal):
    """
    Inspired by Products.CMFPlone.setuphandlers
    """
    language = portal.Language()
    wftool = getToolByName(portal, 'portal_workflow')
    actu_folder = getattr(portal, 'actualites')
    events_folder = getattr(portal, 'evenements')
    # News topic
    if actu_folder:
        actu_folder.title = _(u'Actualités')
        actu_folder.description = _(u'Actualités du site')
        _createObjectByType(
            'Collection',
            portal.actualites,
            id='actualites',
            title=actu_folder.title,
            description=actu_folder.description)

        folder = portal.actualites
        alsoProvides(folder, IFolderViewSelectedContent)
        folder.setConstrainTypesMode(constraintypes.ENABLED)
        folder.setLocallyAllowedTypes(['News Item'])
        folder.setImmediatelyAddableTypes(['News Item'])
        folder.setDefaultPage('actualites')
        folder.unmarkCreationFlag()
        folder.setLanguage(language)
        alsoProvides(folder, IFolderViewSelectedContent)
        publishContent(wftool, folder)

        topic = portal.actualites.actualites
        IFeedSettings(topic).enabled = True
        topic.setLanguage(language)

        query = [{'i': 'portal_type',
                  'o': 'plone.app.querystring.operation.selection.is',
                  'v': ['News Item']},
                 {'i': 'review_state',
                  'o': 'plone.app.querystring.operation.selection.is',
                  'v': ['published']}]
        topic.setQuery(query)

        topic.setSort_on('effective')
        topic.setSort_reversed(True)
        topic.setLayout('summary_view')
        topic.unmarkCreationFlag()
        publishContent(wftool, topic)

    # Events topic
    if events_folder:
        events_folder.title = _(u'Événements')
        events_folder.description = _(u'Événements du site')
        _createObjectByType('Collection', portal.evenements, id='evenements',
                            title=events_folder.title,
                            description=events_folder.description)

        folder = portal.evenements
        alsoProvides(folder, IFolderViewSelectedContent)
        folder.setConstrainTypesMode(constraintypes.ENABLED)
        folder.setLocallyAllowedTypes(['Event'])
        folder.setImmediatelyAddableTypes(['Event'])
        folder.setDefaultPage('evenements')
        folder.unmarkCreationFlag()
        folder.setLanguage(language)
        publishContent(wftool, folder)

        topic = folder.evenements
        IFeedSettings(topic).enabled = True
        topic.unmarkCreationFlag()
        topic.setLanguage(language)

        query = [{'i': 'portal_type',
                  'o': 'plone.app.querystring.operation.selection.is',
                  'v': ['Event']},
                 {'i': 'start',
                  'o': 'plone.app.querystring.operation.date.afterToday',
                  'v': ''},
                 {'i': 'review_state',
                  'o': 'plone.app.querystring.operation.selection.is',
                  'v': ['published']}]
        topic.setQuery(query)
        topic.setSort_on('start')
        topic.setLayout('summary_view')
        publishContent(wftool, topic)


def add_alaune(portal):
    news_folder = getattr(portal, 'actualites', None)
    if news_folder:
        # check if folder is not already provided
        alsoProvides(news_folder, IFolderViewSelectedContent)
    event_folder = getattr(portal, 'evenements', None)
    if event_folder:
        # check if folder is not already provided
        alsoProvides(event_folder, IFolderViewSelectedContent)
    alaune_folder = getattr(portal, 'a-la-une', None)

    if not alaune_folder:
        folder = api.content.create(container=portal,
                                    type='Folder',
                                    id='a-la-une')
        folder.setTitle(_(u'À la une'))
        folder.reindexObject()
        portalPath = api.portal.get().getPhysicalPath()
        contextPath = '/'.join(folder.getPhysicalPath()[len(portalPath):])
        alsoProvides(folder, IFolderViewSelectedContent)
        collection = api.content.create(container=folder,
                                        type='Collection',
                                        id='a-la-une',
                                        title=_(u'À la une'))
        query = [{'i': 'hiddenTags',
                  'o': 'plone.app.querystring.operation.selection.is',
                  'v': 'a-la-une'},
                 {'i': 'path',
                  'o': 'plone.app.querystring.operation.string.path',
                  'v': '/{0}'.format(contextPath)}]
        collection.setQuery(query)
        collection.setSort_on('effective')
        collection.setSort_reversed(True)
        collection.setLayout('summary_view')
        folder.setDefaultPage('a-la-une')
        portal.moveObjectToPosition(folder.id, 1)


def migrateTopicIds(portal):
    pc = getToolByName(portal, 'portal_catalog')
    for brainTopic in pc(portal_type='Topic'):
        topic = brainTopic.getObject()
        topic_parent = topic.aq_parent
        api.content.delete(obj=topic)
        if topic_parent.getId() == 'news':
            api.content.rename(obj=topic_parent, new_id='actualites')
        if topic_parent.getId() == 'events':
            api.content.rename(obj=topic_parent, new_id='evenements')


def setCriterion(portal, folder_name, index, operator, value=None):
    """
    Change existing criterion to collection, or add a new one
    """
    folder = getattr(portal, folder_name, None)
    if folder and getattr(folder, 'index', False):
        collection = folder.index
        if not getattr(collection, 'query', False):
            migrateTopicIds(portal)
            createEventsAndNews(portal)
            folder = getattr(portal, folder_name, None)
            collection = folder.index

        queries = collection.query

        # Remove existing query, usefull for reinstalling too
        for query in queries[:]:
            if query['i'] == index:
                queries.remove(query)

        # Create new query
        new_query = {'i': index,
                     'o': operator}
        if value is not None:
            new_query['v'] = value

        queries.append(new_query)

        collection.setQuery(queries)


def deleteContentRules(portal):
    storage = getUtility(IRuleStorage)
    if 'citizen-move-event' in storage:
        del storage['citizen-move-event']
    if 'citizen-reject-event' in storage:
        del storage['citizen-reject-event']


def create_menu(portal):
    folders = [
        {'ma-commune': 'Ma commune'},
        {'loisirs': 'Loisirs'},
        {'economie': 'Economie'},
        {'je-suis': 'Je suis'},
        {'je-trouve': 'Je trouve'},
    ]
    for f in folders:
        folder_id, folder_name = f.items()[0]
        if not getattr(portal, folder_id, None):
            folder = api.content.create(
                container=portal,
                type='Folder',
                id=folder_id,
            )
            folder.setTitle(folder_name)
            folder.reindexObject()
            api.content.transition(folder, 'publish_and_show')


def add_cookiescuttr(portal):
    api.portal.set_registry_record(
        'collective.cookiecuttr.interfaces.ICookieCuttrSettings.cookiecuttr_enabled',  # noqa
        True)

    api.portal.set_registry_record(
        'collective.cookiecuttr.interfaces.ICookieCuttrSettings.implied_consent',  # noqa
        True)

    api.portal.set_registry_record(
        'collective.cookiecuttr.interfaces.ICookieCuttrSettings.accept_button',
        [{'text': u'Accept cookies', 'language': u'en'},
         {'text': u'Accepter les cookies', 'language': u'fr'}])

    api.portal.set_registry_record(
        'collective.cookiecuttr.interfaces.ICookieCuttrSettings.link',
        [{'text': u'/cookies-page ', 'language': u'en'},
         {'text': u'/cookies-page', 'language': u'fr'}])

    api.portal.set_registry_record(
        'collective.cookiecuttr.interfaces.ICookieCuttrSettings.text',
        [{'text': u"We use cookies. <a href='{{cookiePolicyLink}}' title='read about our cookies'> Read everything </a>", 'language': u'en'},  # noqa
         {'text': u"Nous utilisons des cookies pour faciliter la navigation et le partage social. <a href='{{cookiePolicyLink}}' title='read about our cookies'> Plus d\'informations </a>", 'language': u'fr'}])  # noqa


def set_scales_for_image_cropping():
    """This is made in setuphandler beacause propertiestool.xml must be
    charged before adding scales for image cropping"""
    crop_allowed = [
        'slider', 'collection', 'header', 'banner', 'visuel', 'multimedia']
    api.portal.set_registry_record(
        'plone.app.imagecropping.browser.settings.ISettings.cropping_for',
        crop_allowed)


def enable_sitemap(context, logger=None):
    pprop = getToolByName(context, 'portal_properties')
    site_properties = pprop.site_properties
    site_properties.exposeDCMetaTags = True
    site_properties.enable_sitemap = True


def add_mail_host(context=None):
    mailhost = api.portal.get_tool('MailHost')
    mailhost.smtp_queue = True
    smtp_queue_directory = os.environ.get(
        'SMTP_QUEUE_DIRECTORY',
        '/home/imio/imio-website/var/mailhost/queue')
    mailhost.smtp_queue_directory = smtp_queue_directory
    # mailhost.smtp_host = 'mailrelay.imio.be'
    mailhost.smtp_host = 'mailrelay.imio.be'
    mailhost.smtp_port = 25
    mailhost._stopQueueProcessorThread()
    mailhost._startQueueProcessorThread()
    mailhost.manage_restartQueueThread()


def use_email_as_login():
    pprop = api.portal.get_tool('portal_properties')
    site_properties = pprop.site_properties
    site_properties.manage_changeProperties(use_email_as_login=True)


def set_contact_worflow():
    portal = api.portal.get()
    portal_workflow = api.portal.get_tool('portal_workflow')
    workflow = portal_workflow.getWorkflowsFor('organization')
    if len(workflow) > 1:
        logger.info(u'To much workflow for contacts.')
        return
    if len(workflow) == 0:
        logger.info(u'No workflow for contacts.')
        return
    workflow_id = workflow[0].id
    if workflow_id == 'cpskin_collective_contact_workflow':
        logger.info(u'cpskin_collective_contact_workflow already set.')
        return
    chain = ('cpskin_collective_contact_workflow',)
    types = ('held_position',
             'organization',
             'person',
             'position')
    state_map = {'active': 'active',
                 'deactivated': 'deactivated'}
    remap_workflow(portal, type_ids=types, chain=chain,
                   state_map=state_map)
    util = queryUtility(IRAMCache)
    if util is not None:
        util.invalidateAll()


def ensure_folder_ordering():
    old_order_key = DefaultOrdering.ORDER_KEY
    logger = logging.getLogger("cpskin.policy")
    portal_catalog = api.portal.get_tool("portal_catalog")
    brains = portal_catalog({"portal_type": "Folder"})
    for brain in brains:
        obj = brain.getObject()
        if obj and obj._ordering == "unordered":
            annotations = IAnnotations(obj)
            if old_order_key in annotations:
                # old order stuff remained in annotation and can breaks
                # objectIds() with missing old stored objects ids
                del annotations[old_order_key]
            obj.setOrdering(u"")
            order = obj.getOrdering()
            for id in obj._tree:
                if id not in order._order():
                    order.notifyAdded(id)
            logger.info("Fixed ordering for folder : {}".format(brain.getURL()))



# -*- coding: utf-8 -*-

version = "4.3.52"

from setuptools import setup, find_packages

long_description = (
    open("README.rst").read() + "\n" + "\n" + open("CHANGES.rst").read() + "\n"
)

setup(
    name="cpskin.policy",
    version=version,
    description="Policy package for cpskin",
    long_description=long_description,
    classifiers=[
        "Environment :: Web Environment",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.7",
        "Framework :: Plone",
        "Framework :: Plone :: 4.2",
        "Framework :: Plone :: 4.3",
    ],
    keywords="",
    author="IMIO",
    author_email="support@imio.be",
    url="https://github.com/imio/cpskin.policy",
    license="gpl",
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        "setuptools",
        "Plone",
        "collective.contentrules.runscript",
        "collective.geotransform",
        "cpskin.agenda",
        "cpskin.caching",
        "cpskin.contenttypes",
        "cpskin.core",
        "cpskin.diazotheme.newDream",
        "cpskin.menu",
        "cpskin.minisite",
        "cpskin.slider",
        "cpskin.theme",
        "cpskin.workflow",
        "collective.directory",
        "Products.PasswordStrength",
        "collective.jekyll",
        "Products.PloneFormGen",
        "Products.PloneGazette",
        "Solgema.fullcalendar",
        "collective.atomrss",
        "collective.monitor",
        "collective.cookiecuttr",
        "plone.app.imagecropping",
        "imio.migrator",
        "collective.excelexport",
        "collective.autoscaling",
        "collective.preventactions",
        "collective.recaptcha",
        "collective.sendinblue",
        "collective.limitfilesizepanel",
        "plone.restapi",
        "collective.behavior.targetblank",
        "collective.autopublishing",
        "collective.folderishtypes",
        "pas.plugins.imio",
        "collective.captchacontactinfo",
        "imio.prometheus",
        "collective.anysurfer",
    ],
    extras_require=dict(
        test=[
            "plone.app.robotframework",
            "cpskin.demo",
            "plone.app.multilingual",
            "Products.contentmigration",
        ]
    ),
    entry_points={},
)



# -*- coding: utf-8 -*-
from Products.CMFPlone import interfaces
from Products.CMFQuickInstallerTool import interfaces as quiskinstallinterfaces
from zope.interface import implements


class HiddenProfiles(object):
    implements(interfaces.INonInstallable)

    def getNonInstallableProfiles(self):
        """Hides profiles from 'Add Plone site' form"""
        return [u'cpskin.contenttypes:default',
                u'cpskin.core:default',
                u'cpskin.core:members-configuration',
                u'cpskin.core:uninstall',
                u'cpskin.menu:default',
                u'cpskin.menu:uninstall',
                u'cpskin.minisite:default',
                u'cpskin.minisite:uninstall',
                u'cpskin.policy:uninstall',
                u'cpskin.slider:default',
                u'cpskin.slider:uninstall',
                u'cpskin.theme:default',
                u'cpskin.theme:members-configuration',
                u'cpskin.theme:uninstall',
                u'cpskin.workflow:default',
                u'cpskin.workflow:members-configuration',
                u'cpskin.workflow:uninstall',
                u'collective.directory:uninstall',
                ]


class HiddenProducts(object):
    implements(quiskinstallinterfaces.INonInstallable)

    def getNonInstallableProducts(self):
        """Hides profiles from QuickInstaller"""
        return [u'cpskin.core',
                u'cpskin.locales',
                u'cpskin.menu',
                u'cpskin.minisite',
                u'cpskin.policy',
                u'cpskin.slider',
                u'cpskin.theme',
                u'cpskin.workflow']
